# coding: utf-8

"""
    Automio API

    Documentation of API endpoints of Automio for SDK

    The version of the OpenAPI document: 0.1.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from automio.models.application_file_download_response import ApplicationFileDownloadResponse

class TestApplicationFileDownloadResponse(unittest.TestCase):
    """ApplicationFileDownloadResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApplicationFileDownloadResponse:
        """Test ApplicationFileDownloadResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApplicationFileDownloadResponse`
        """
        model = ApplicationFileDownloadResponse()
        if include_optional:
            return ApplicationFileDownloadResponse(
                bucket_name = '',
                path = '',
                object_key = '',
                public_url = ''
            )
        else:
            return ApplicationFileDownloadResponse(
                bucket_name = '',
                path = '',
                object_key = '',
                public_url = '',
        )
        """

    def testApplicationFileDownloadResponse(self):
        """Test ApplicationFileDownloadResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
