# coding: utf-8

"""
    Automio API

    Documentation of API endpoints of Automio for SDK

    The version of the OpenAPI document: 0.1.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from automio.models.get_integrations200_response_results_inner_one_of import GetIntegrations200ResponseResultsInnerOneOf

class TestGetIntegrations200ResponseResultsInnerOneOf(unittest.TestCase):
    """GetIntegrations200ResponseResultsInnerOneOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetIntegrations200ResponseResultsInnerOneOf:
        """Test GetIntegrations200ResponseResultsInnerOneOf
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetIntegrations200ResponseResultsInnerOneOf`
        """
        model = GetIntegrations200ResponseResultsInnerOneOf()
        if include_optional:
            return GetIntegrations200ResponseResultsInnerOneOf(
                count = 56,
                next = '',
                previous = '',
                results = [
                    { }
                    ]
            )
        else:
            return GetIntegrations200ResponseResultsInnerOneOf(
                count = 56,
                results = [
                    { }
                    ],
        )
        """

    def testGetIntegrations200ResponseResultsInnerOneOf(self):
        """Test GetIntegrations200ResponseResultsInnerOneOf"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
