# coding: utf-8

"""
    Automio API

    Documentation of API endpoints of Automio for SDK

    The version of the OpenAPI document: 0.1.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from automio.models.get_integrations200_response import GetIntegrations200Response

class TestGetIntegrations200Response(unittest.TestCase):
    """GetIntegrations200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetIntegrations200Response:
        """Test GetIntegrations200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetIntegrations200Response`
        """
        model = GetIntegrations200Response()
        if include_optional:
            return GetIntegrations200Response(
                count = 123,
                next = 'http://api.example.org/accounts/?page=4',
                previous = 'http://api.example.org/accounts/?page=2',
                results = [
                    null
                    ]
            )
        else:
            return GetIntegrations200Response(
                count = 123,
                results = [
                    null
                    ],
        )
        """

    def testGetIntegrations200Response(self):
        """Test GetIntegrations200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
