# coding: utf-8

"""
    Automio API

    Documentation of API endpoints of Automio for SDK

    The version of the OpenAPI document: 0.1.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from automio.api.applications_files_api import ApplicationsFilesApi


class TestApplicationsFilesApi(unittest.TestCase):
    """ApplicationsFilesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationsFilesApi()

    def tearDown(self) -> None:
        pass

    def test_apps_files_download_retrieve(self) -> None:
        """Test case for apps_files_download_retrieve

        Resolve application file URL
        """
        pass

    def test_apps_files_upload_create(self) -> None:
        """Test case for apps_files_upload_create

        Upload application file
        """
        pass


if __name__ == '__main__':
    unittest.main()
